==> blanco.plugin.constants_0.6.0-src.zip: blancoConstantsPlugin/src/blanco/plugin/constants/wizards/BlancoConstantsWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.constants.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoConstantsWizardPage4 extends WizardPage {
    public BlancoConstantsWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle("blancoConstantsvOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoConstantsvOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE)
                .setText("  2.^fBNg (tH_ meta/constants ܂)");
        new Label(container, SWT.NONE).setText("    萔`i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE)
                .setText("  4.\[XR[hfBNg (tH_ blanco/main ƂȂ܂)");

        setControl(container);
    }
}

==> blanco.plugin.constants_0.9.3-src.zip: blancoConstantsPlugin/src/blanco/plugin/constants/wizards/BlancoConstantsWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.constants.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoConstantsWizardPage4 extends WizardPage {
    public BlancoConstantsWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle("blancoConstantsvOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoConstantsvOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE)
                .setText("  2.^fBNg (tH_ meta/constants ܂)");
        new Label(container, SWT.NONE).setText("    萔`i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE).setText("  4.ꂽ\[XR[hi[tH_");
        new Label(container, SWT.NONE).setText("    Eblanco/main (Java)");

        setControl(container);
    }
}
